﻿# This file is in the public domain. Feel free to modify it as a basis
# for your own screens.

##############################################################################
# Say
#
# Screen that's used to display adv-mode dialogue.
# http://www.renpy.org/doc/html/screen_special.html#say
screen say:

    # Defaults for side_image and two_window
    default side_image = None
    default two_window = False

    # Decide if we want to use the one-window or two-window varaint.
    if not two_window:

        # The one window variant.        
        window:
            id "window"

            has vbox:
                style "say_vbox"

            if who:
                text who id "who"

            text what id "what"

    else:

        # The two window variant.
        vbox:
            style "say_two_window_vbox"

            if who:            
                window:
                    style "say_who_window"

                    text who:
                        id "who"
                        
            window:
                id "window"

                has vbox:
                    style "say_vbox"

                text what id "what"
              
    # If there's a side image, display it above the text.
    if side_image:
        add side_image
    else:
        add SideImage() xalign 0.0 yalign 1.0

    # Use the quick menu.
    use quick_menu


##############################################################################
# Choice
#
# Screen that's used to display in-game menus.
# http://www.renpy.org/doc/html/screen_special.html#choice

screen choice:

    window: 
        style "menu_window"        
        xalign 0.5
        yalign 0.5
        
        vbox:
            style "menu"
            spacing 2
            
            for caption, action, chosen in items:
                
                if action:  
                    
                    button:
                        action action
                        style "menu_choice_button"                        

                        text caption style "menu_choice"
                    
                else:
                    text caption style "menu_caption"

init -2 python:
    config.narrator_menu = True
    
    style.menu_window.set_parent(style.default)
    style.menu_choice.set_parent(style.button_text)
    style.menu_choice.clear()
    style.menu_choice_button.set_parent(style.button)
    style.menu_choice_button.xminimum = int(config.screen_width * 0.75)
    style.menu_choice_button.xmaximum = int(config.screen_width * 0.75)


##############################################################################
# Input
#
# Screen that's used to display renpy.input()
# http://www.renpy.org/doc/html/screen_special.html#input

screen input:

    window:
        has vbox

        text prompt
        input id "input"

    use quick_menu
        
##############################################################################
# Nvl
#
# Screen used for nvl-mode dialogue and menus.
# http://www.renpy.org/doc/html/screen_special.html#nvl

screen nvl:

    window:
        style "nvl_window"

        has vbox:
            style "nvl_vbox"

        # Display dialogue.
        for who, what, who_id, what_id, window_id in dialogue:
            window:
                id window_id

                has hbox:
                    spacing 10

                if who is not None:
                    text who id who_id

                text what id what_id

        # Display a menu, if given.
        if items:

            vbox:
                id "menu"

                for caption, action, chosen in items:

                    if action:

                        button:
                            style "nvl_menu_choice_button"
                            action action

                            text caption style "nvl_menu_choice"

                    else:

                        text caption style "nvl_dialogue"

    add SideImage() xalign 0.0 yalign 1.0
    
    use quick_menu
        
##############################################################################
# Main Menu 
#
# Screen that's used to display the main menu, when Ren'Py first starts
# http://www.renpy.org/doc/html/screen_special.html#main-menu

screen main_menu:
    tag menu
   
    window:
        style "mm_root"
        
      
    imagebutton:
        action Start()
        idle "gui/start_unhover.png"
        hover "gui/start_hover.png"
        xanchor .5 yanchor 0.5
        xpos .5 ypos .42
    imagebutton:
        action ShowMenu("load")
        idle "gui/load_unhover.png"
        hover "gui/load_hover.png"      
        xanchor .5 yanchor 0.5
        xpos .5 ypos .54
    imagebutton:
        action ShowMenu("preferences")
        idle "gui/pref_unhover.png"
        hover "gui/pref_hover.png"         
        xanchor .5 yanchor 0.5
        xpos .5 ypos .66           
    imagebutton:
        action ShowMenu("mygallery")
        idle "gui/extras_unhover.png"
        hover "gui/extras_hover.png"         
        xanchor .5 yanchor 0.5
        xpos .5 ypos .78
    imagebutton:
        action Quit(confirm=False)
        idle "gui/quit_unhover.png"
        hover "gui/quit_hover.png"         
        xanchor .5 yanchor 0.5
        xpos .5 ypos .9            
               


#screen main_menu:

    # This ensures that any other menu screen is replaced.
#    tag menu

    # The background of the main menu.
#    window:
#        style "mm_root"

    # The main menu buttons.
#    frame:
#        background None
#        style_group "mm"
#        xalign .5
#        yalign .82
        
#        has hbox

#        textbutton _("{size=+10}{font=Daisyregular.ttf}Start Game{/font}{/size}") action Start()
#        textbutton _("{size=+10}{font=Daisyregular.ttf}Load Game{/font}{/size}") action ShowMenu("load")

#    frame:
#        background None
#        style_group "mm"
#        xalign .5
#        yalign .88
        
#        has hbox
        
#        textbutton _("{size=+10}{font=Daisyregular.ttf}Extras{/font}{/size}") action ShowMenu("load")        
#        textbutton _("{size=+10}{font=Daisyregular.ttf}Preferences{/font}{/size}") action ShowMenu("preferences")

#    frame:
#        background None
#        style_group "mm"
#        xalign .5
#        yalign .94
        
#        has hbox        
        
#        textbutton _("{size=+10}{font=Daisyregular.ttf}Help{/font}{/size}") action Help()
#        textbutton _("{size=+10}{font=Daisyregular.ttf}Quit{/font}{/size}") action Quit(confirm=False)

init -2 python:

    # Make all the main menu buttons be the same size.
    style.mm_button.size_group = "mm"


##############################################################################
# Navigation
#
# Screen that's included in other screens to display the game menu
# navigation and background.
# http://www.renpy.org/doc/html/screen_special.html#navigation
screen navigation:

    # The background of the game menu.
    window:
        style "gm_root"

    # The various buttons.
    frame:
        background None
        style_group "gm_nav"
        xalign .5
        yalign .03
        
        has hbox

        textbutton _("{size=+10}{font=Daisyregular.ttf}Return{/font}{/size}") action Return()
        textbutton _("{size=+10}{font=Daisyregular.ttf}Preferences{/font}{/size}") action ShowMenu("preferences")
        textbutton _("{size=+10}{font=Daisyregular.ttf}Save Game{/font}{/size}") action ShowMenu("save")
        textbutton _("{size=+10}{font=Daisyregular.ttf}Load Game{/font}{/size}") action ShowMenu("load")
        
    frame:
        background None
        style_group "gm_nav"
        xalign .5
        yalign .08
        
        has hbox
        
        textbutton _("{size=+10}{font=Daisyregular.ttf}Main Menu{/font}{/size}") action MainMenu()
        textbutton _("{size=+10}{font=Daisyregular.ttf}Help{/font}{/size}") action Help()
        textbutton _("{size=+10}{font=Daisyregular.ttf}Quit{/font}{/size}") action Quit()

init -2 python:
    style.gm_nav_button.size_group = "gm_nav"
    

##############################################################################
# Save, Load
#
# Screens that allow the user to save and load the game.
# http://www.renpy.org/doc/html/screen_special.html#save
# http://www.renpy.org/doc/html/screen_special.html#load

# Since saving and loading are so similar, we combine them into
# a single screen, file_picker. We then use the file_picker screen
# from simple load and save screens.
    
screen file_picker:

    frame:
        #style "file_picker_frame"
        background None
        yoffset 120 
        has hbox

        # The buttons at the top allow the user to pick a
        # page of files.
        vbox:
            xpos 100
            style_group "file_picker_nav"
            
            textbutton _(" Previous Page  "):
                action FilePagePrevious()
                #background "gui/emptysel.png"
                #hover "gui/emptyhover.png"
                
#            textbutton _("Auto"):
#                action FilePage("auto")

#            textbutton _("Quick"):
#                action FilePage("quick")

            for i in range(1, 6):
                #textbutton str(i):
                vbox:
                    yminimum 200
                    #xpos 50
                    label _(" ")
                    textbutton _(" Slots Page [i]   "):
                       
                        action FilePage(i)
                        #background "gui/emptyunsel.png"
                        #hover "gui/emptyhover.png"
                        #selected_idle "gui/emptysel.png"

            label _(" ")             
            textbutton _(" Next Page     "):
                action FilePageNext()
                #background "gui/emptysel.png"
                #hover "gui/emptyhover.png"
                
        $ columns = 1
        $ rows = 4
                
        # Display a grid of file slots.
        grid columns rows:
            transpose True
            xfill True
#            yfill True
            xpos 200
            xmaximum 520
            style_group "file_picker"
            
            # Display ten file slots, numbered 1 - 10.
            for i in range(1, columns * rows + 1):

                # Each file slot is a button.
                button:
                    action FileAction(i)
                    xfill True
                    yminimum 145
                    has hbox

                    # Add the screenshot.
                    add FileScreenshot(i)
                    
                    # Format the description, and add it as text.
                    $ description = "% 2s. %s\n%s" % (
                        FileSlotName(i, columns * rows),
                        FileTime(i, empty=_("Empty Slot.")),
                        FileSaveName(i))

                    text description

                    key "save_delete" action FileDelete(i)
                    
                    
screen save:

    # This ensures that any other menu screen is replaced.
    tag menu
    use navigation

    frame:
        background None
        #foreground "savethis"
        #xalign 0.25
        #yalign 0.5    
        
    use file_picker        

screen load:

    # This ensures that any other menu screen is replaced.
    tag menu

    use navigation

    frame:
        background None
        #foreground "loadthis"
        #xalign 0.25
        #yalign 0.5    
        
    use file_picker  

init -2 python:
#    style.file_picker_frame = Style(style.menu_frame)

    style.file_picker_nav_button = Style(style.small_button)
    style.file_picker_nav_button_text = Style(style.small_button_text)

    style.file_picker_button = Style(style.large_button)
    style.file_picker_button.ypadding = 10

    style.file_picker_text = Style(style.large_button_text)

    config.thumbnail_width = 160
    config.thumbnail_height = 120

##############################################################################
# Preferences
#
# Screen that allows the user to change the preferences.
# http://www.renpy.org/doc/html/screen_special.html#prefereces
    
screen preferences:

    tag menu

    # Include the navigation.
    use navigation

    frame:
        background None
        #foreground "optionsthis"
        #xalign 0.25
        #yalign 0.5   

    # Put the navigation columns in a three-wide grid.
    grid 4 1:
        style_group "prefs"
        xfill True

        vbox:
            yoffset 120
            frame:
                background None
                style_group "pref"
                
        # The left column.
        vbox:     
            yoffset 120
            frame:
                style_group "pref"
                has vbox

                label _("Text Speed")
                bar value Preference("text speed")
                
            frame:
                style_group "pref"
                has vbox

                label _("Auto-Forward Time")
                bar value Preference("auto-forward time")

            frame:
                style_group "pref"
                has vbox

                label _("Music Volume")
                bar value Preference("music volume")

            frame:
                style_group "pref"
                has vbox

                label _("Sound Volume")
                bar value Preference("sound volume")

                if config.sample_sound:
                    textbutton "Test":
                        action Play("sound", config.sample_sound)
                        style "soundtest_button"

            #frame:
                #style_group "pref"
                #has vbox

                #label _("Voice Volume")
                #bar value Preference("voice volume")

                #if config.sample_voice:
                    #textbutton "Test":
                        #action Play("voice", config.sample_voice)
                        #style "soundtest_button"

            frame:
                style_group "pref"
                has vbox

                textbutton _("Joystick...") action Preference("joystick")

        vbox:
            yoffset 120
            frame:
                style_group "pref"
                has vbox

                label _("Display")
                #textbutton _("Window") action Preference("display", "window")
                #textbutton _("Fullscreen") action Preference("display", "fullscreen")
                textbutton _("Window"):
                    action Preference("display", "window")
                      
                textbutton _("Fullscreen"):
                    action Preference("display", "fullscreen")
                     
                
            frame:
                style_group "pref"
                has vbox

                label _("Transitions")
                #textbutton _("All") action Preference("transitions", "all")
                #textbutton _("None") action Preference("transitions", "none")
                textbutton _("All Transitions"):
                    action Preference("transitions", "all")
                    
                textbutton _("No Transitions"):
                    action Preference("transitions", "none")
                
            frame:
                style_group "pref"
                has vbox

                label _("Skip")
#                textbutton _("Seen Messages") action Preference("skip", "seen")
#                textbutton _("All Messages") action Preference("skip", "all")
                textbutton _("Seen"):
                    action Preference("skip", "seen")
  
                textbutton _("All"):
                    action Preference("skip", "all")
   
              
                        
        vbox:
            yoffset 60
            frame:
                background None
                style_group "pref"
                
init -2 python:
    style.pref_frame.xfill = True
    style.pref_frame.xmargin = 5
    style.pref_frame.top_margin = 5

    style.pref_vbox.xfill = True

    style.pref_button.size_group = "pref"
    style.pref_button.xalign = 1.0

    style.pref_slider.xmaximum = 218 #192
    style.pref_slider.ymaximum = 20
    style.pref_slider.xalign = 1.0

    style.soundtest_button.xalign = 1.0
    style.pref_label_text.size = 28
    style.pref_label_text.drop_shadow = [(2, 2)]

#    style.pref_slider.left_bar = "gui/bar_full.png"
#    style.pref_slider.right_bar = "gui/bar_empty.png"
#    style.pref_slider.hover_left_bar = "gui/bar_hover.png"
    
#    style.pref_slider.thumb = "gui/slider_thumb.png"
#   style.pref_slider.thumb_offset = 6
#    style.pref_slider.thumb_shadow = None        
    


##############################################################################
# Yes/No Prompt
#
# Screen that asks the user a yes or no question.
# http://www.renpy.org/doc/html/screen_special.html#yesno-prompt
    
screen yesno_prompt:

    modal True

    window:
        style "gm_root"

    frame:
        style_group "yesno"
        background "gui/txtbxfm.png"

        xfill True
        xmargin .05
        ypos .1
        yanchor 0
        ypadding .05
        
        has vbox:
            xalign .5
            yalign .5
            spacing 30
            
        label _(message):
            xalign 0.5

        hbox:
            xalign 0.5
            spacing 100
            
            textbutton _("Yes") action yes_action
            textbutton _("No") action no_action


init -2 python:    
    style.yesno_button.size_group = "yesno"
    style.yesno_label_text.text_align = 0.5


##############################################################################
# Quick Menu
#
# A screen that's included by the default say screen, and adds quick access to
# several useful functions.
screen quick_menu:

    # Add an in-game quick menu.
    hbox:
        style_group "quick"
    
        xalign 0.93
        yalign 0.76

        textbutton _("{size=+10}Q.Save{/size}") action QuickSave()
        textbutton _("{size=+10}Q.Load{/size}") action QuickLoad()
        textbutton _("{size=+10}Save{/size}") action ShowMenu('save')
        textbutton _("{size=+10}Skip{/size}") action Skip()
        textbutton _("{size=+10}Auto{/size}") action Preference("auto-forward", "toggle")
        textbutton _("{size=+10}Prefs{/size}") action ShowMenu('preferences')
        
init -2 python:
    style.quick_button.set_parent('default')
    style.quick_button.background = None
    style.quick_button.xpadding = 5

    style.quick_button_text.set_parent('default')
    style.quick_button_text.size = 12
    style.quick_button_text.idle_color = "#ccc"
    style.quick_button_text.hover_color = "#ffffff"
    style.quick_button_text.selected_idle_color = "#cc0"
    style.quick_button_text.selected_hover_color = "#FEFD81"
    style.quick_button_text.insensitive_color = "#4448"

    style.pref_label_text.drop_shadow = [(2, 2)]

     
    # Set a default value for the auto-forward time, and note that AFM is
    # turned off by default.
    config.default_afm_time = 10
    config.default_afm_enable = False

init python:

    # Step 1. Create a MusicRoom instance.
    mr = MusicRoom(fadeout=1.0)

    # Step 2. Add music files.

    mr.add("sounds/normal2.ogg", always_unlocked=True)
    mr.add("sounds/normal1.ogg", always_unlocked=True)
    mr.add("sounds/ecchi1.ogg", always_unlocked=True)     
    mr.add("sounds/yurinormal2.ogg", always_unlocked=True)
    mr.add("sounds/yuriecchi2.ogg", always_unlocked=True)
    mr.add("sounds/why.ogg", always_unlocked=True)
    mr.add("sounds/title.ogg", always_unlocked=True)  
    mr.add("sounds/yurifunny.ogg", always_unlocked=True)    
    
init python:

    # Step 1. Create the gallery object.
    g = Gallery()

    # Step 2. Add buttons and images to the gallery.
 #   style.g.button.background=None
 #  style.g.button.hover_background=None

    # This button has multiple images assocated with it. We use unlock_image
    # so we don't have to call both .image and .unlock. We also apply a
    # transform to the first image.
    
    g.button("cakepan1")
    g.unlock_image("hcg1_1")
    g.unlock_image("hcg1_2")
    g.unlock_image("hcg1_3")    
    g.unlock_image("hcg1_4")
    g.unlock_image("hcg1_5")
    g.unlock_image("hcg1_6")
    g.unlock_image("hcg1_7")
    
    g.button("cakepan2")
    g.unlock_image("hcg2_1")
    g.unlock_image("hcg2_2")
    g.unlock_image("hcg2_3")    
    g.unlock_image("hcg2_4")

    g.button("cakepan3")
    g.unlock_image("hcg3_1")
    g.unlock_image("hcg3_2")

    g.button("cakepan4")
    g.unlock_image("hcg4_1")
    g.unlock_image("hcg4_2")
    g.unlock_image("hcg4_3")    
    g.unlock_image("hcg4_4")
    g.unlock_image("hcg4_5")
    g.unlock_image("hcg4_6")

    g.button("cakepan5")
    g.unlock_image("hcg5_1")
    g.unlock_image("hcg5_2")
    g.unlock_image("hcg5_3")    
 
    g.button("cakepan6")
    g.unlock_image("hcg6_1")
    g.unlock_image("hcg6_2")

    g.button("cakepan7")
    g.unlock_image("hcg7_1")
    g.unlock_image("hcg7_2")
    g.unlock_image("hcg7_3")    
    g.unlock_image("hcg7_4")
    g.unlock_image("hcg7_5")
    g.unlock_image("hcg7_6")
    g.unlock_image("hcg7_7")    
    g.unlock_image("hcg7_8")
    g.unlock_image("hcg7_9")
    g.unlock_image("hcg7_10")    
    
    g.button("cakepan8")
    g.unlock_image("hcg8_1")
    g.unlock_image("hcg8_2")
    g.unlock_image("hcg8_3")    
    g.unlock_image("hcg8_4")
    
    g.button("cakepan9")    
    g.unlock_image("hcg9_1")
    g.unlock_image("hcg9_2")
    g.unlock_image("hcg9_3")    
    
    # The transition used when switching images.
    g.transition = dissolve
   
# Step 3. The gallery screen we use.
screen mygallery:
    tag menu

    use navigation    

    window:
        background None
        foreground "gui/option.png"    
    add g.make_button("cakepan1", "gui/circlehcg1.png", "gui/circlehcg1lock.png", "gui/circlehcg1hover.png", xanchor = 0, yanchor = 0, xalign = 0, yalign = 0, xpos = 239, ypos = 160, xmargin = 0, ymargin = 0, background = None)
    add g.make_button("cakepan2", "gui/circlehcg2.png", "gui/circlehcg2lock.png", "gui/circlehcg2hover.png", xanchor = 0, yanchor = 0, xalign = 0, yalign = 0, xpos = 427, ypos = 160, xmargin = 0, ymargin = 0, background = None)
    add g.make_button("cakepan3", "gui/circlehcg3.png", "gui/circlehcg3lock.png", "gui/circlehcg3hover.png", xanchor = 0, yanchor = 0, xalign = 0, yalign = 0, xpos = 617, ypos = 160, xmargin = 0, ymargin = 0, background = None)
    add g.make_button("cakepan4", "gui/circlehcg4.png", "gui/circlehcg4lock.png", "gui/circlehcg4hover.png", xanchor = 0, yanchor = 0, xalign = 0, yalign = 0, xpos = 239, ypos = 345, xmargin = 0, ymargin = 0, background = None)
    add g.make_button("cakepan5", "gui/circlehcg5.png", "gui/circlehcg5lock.png", "gui/circlehcg5hover.png", xanchor = 0, yanchor = 0, xalign = 0, yalign = 0, xpos = 427, ypos = 345, xmargin = 0, ymargin = 0, background = None)    
    add g.make_button("cakepan6", "gui/circlehcg6.png", "gui/circlehcg6lock.png", "gui/circlehcg6hover.png", xanchor = 0, yanchor = 0, xalign = 0, yalign = 0, xpos = 617, ypos = 345, xmargin = 0, ymargin = 0, background = None)
    add g.make_button("cakepan7", "gui/circlehcg7.png", "gui/circlehcg7lock.png", "gui/circlehcg7hover.png", xanchor = 0, yanchor = 0, xalign = 0, yalign = 0, xpos = 239, ypos = 533, xmargin = 0, ymargin = 0, background = None)
    add g.make_button("cakepan8", "gui/circlehcg8.png", "gui/circlehcg8lock.png", "gui/circlehcg8hover.png", xanchor = 0, yanchor = 0, xalign = 0, yalign = 0, xpos = 427, ypos = 533, xmargin = 0, ymargin = 0, background = None)
    add g.make_button("cakepan9", "gui/circlehcg9.png", "gui/circlehcg9lock.png", "gui/circlehcg9hover.png", xanchor = 0, yanchor = 0, xalign = 0, yalign = 0, xpos = 617, ypos = 533, xmargin = 0, ymargin = 0, background = None)
    

        
    frame:
        xpos 10
        ypos 120
        has vbox:
            xalign 0.5 
            yalign 0.5

        # The buttons that play each track.
        textbutton "Sup Girl" action mr.Play("sounds/normal2.ogg")
        textbutton "Customers Ho!" action mr.Play("sounds/normal1.ogg")
        textbutton "Onee-chan" action mr.Play("sounds/ecchi1.ogg")
        textbutton "Girl Bonding" action mr.Play("sounds/yurinormal2.ogg")
        textbutton "I Wuv You" action mr.Play("sounds/yuriecchi2.ogg")
        textbutton "My Situation" action mr.Play("sounds/why.ogg")
        textbutton "Main Theme" action mr.Play("sounds/title.ogg")        
        textbutton "Bring it On!" action mr.Play("sounds/yurifunny.ogg")
     
    frame:
        xpos 10
        ypos 430
        has hbox:
            xalign 0.5
            yalign 0.5
             
        # Buttons that let us advance tracks.
        textbutton "|<<" action mr.Previous()        
        textbutton ">>|" action mr.Next()

        
    # Start the music playing on entry to the music room.
    on "replace" action mr.Play()

    # Restore the main menu music upon leaving.
#    on "replaced" action Play("music", "sounds/title.gg")